==> usrp-0.10.tar.gz: usrp-0.10/host/swig/usrp_prims.py <==
# This file was created automatically by SWIG 1.3.27.
# Don't modify this file, modify the SWIG interface instead.

import _usrp_prims

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if hasattr(self,name) or (name in ("this", "thisown")):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


ULS_ERROR = _usrp_prims.ULS_ERROR
ULS_OK = _usrp_prims.ULS_OK
ULS_ALREADY_LOADED = _usrp_prims.ULS_ALREADY_LOADED

usrp_one_time_init = _usrp_prims.usrp_one_time_init

usrp_rescan = _usrp_prims.usrp_rescan

usrp_usrp_p = _usrp_prims.usrp_usrp_p

usrp_usrp0_p = _usrp_prims.usrp_usrp0_p

usrp_usrp1_p = _usrp_prims.usrp_usrp1_p

usrp_usrp2_p = _usrp_prims.usrp_usrp2_p

usrp_fx2_p = _usrp_prims.usrp_fx2_p

usrp_unconfigured_usrp_p = _usrp_prims.usrp_unconfigured_usrp_p

usrp_configured_usrp_p = _usrp_prims.usrp_configured_usrp_p

usrp_open_cmd_interface = _usrp_prims.usrp_open_cmd_interface

usrp_open_rx_interface = _usrp_prims.usrp_open_rx_interface

usrp_open_tx_interface = _usrp_prims.usrp_open_tx_interface

usrp_close_interface = _usrp_prims.usrp_close_interface

usrp_load_firmware = _usrp_prims.usrp_load_firmware

usrp_load_firmware_nth = _usrp_prims.usrp_load_firmware_nth

usrp_load_fpga = _usrp_prims.usrp_load_fpga

usrp_load_standard_bits = _usrp_prims.usrp_load_standard_bits
FR_TX_SAMPLE_RATE_DIV = _usrp_prims.FR_TX_SAMPLE_RATE_DIV
FR_RX_SAMPLE_RATE_DIV = _usrp_prims.FR_RX_SAMPLE_RATE_DIV
FR_MASTER_CTRL = _usrp_prims.FR_MASTER_CTRL
bmFR_MC_ENABLE_TX = _usrp_prims.bmFR_MC_ENABLE_TX
bmFR_MC_ENABLE_RX = _usrp_prims.bmFR_MC_ENABLE_RX
bmFR_MC_RESET_TX = _usrp_prims.bmFR_MC_RESET_TX
bmFR_MC_RESET_RX = _usrp_prims.bmFR_MC_RESET_RX
FR_OE_0 = _usrp_prims.FR_OE_0
FR_OE_1 = _usrp_prims.FR_OE_1
FR_OE_2 = _usrp_prims.FR_OE_2
FR_OE_3 = _usrp_prims.FR_OE_3
FR_IO_0 = _usrp_prims.FR_IO_0
FR_IO_1 = _usrp_prims.FR_IO_1
FR_IO_2 = _usrp_prims.FR_IO_2
FR_IO_3 = _usrp_prims.FR_IO_3
FR_MODE = _usrp_prims.FR_MODE
bmFR_MODE_NORMAL = _usrp_prims.bmFR_MODE_NORMAL
bmFR_MODE_LOOPBACK = _usrp_prims.bmFR_MODE_LOOPBACK
bmFR_MODE_RX_COUNTING = _usrp_prims.bmFR_MODE_RX_COUNTING
FR_DEBUG_EN = _usrp_prims.FR_DEBUG_EN
bmFR_DEBUG_EN_TX_A = _usrp_prims.bmFR_DEBUG_EN_TX_A
bmFR_DEBUG_EN_RX_A = _usrp_prims.bmFR_DEBUG_EN_RX_A
bmFR_DEBUG_EN_TX_B = _usrp_prims.bmFR_DEBUG_EN_TX_B
bmFR_DEBUG_EN_RX_B = _usrp_prims.bmFR_DEBUG_EN_RX_B
FR_DC_OFFSET_CL_EN = _usrp_prims.FR_DC_OFFSET_CL_EN
FR_ADC_OFFSET_0 = _usrp_prims.FR_ADC_OFFSET_0
FR_ADC_OFFSET_1 = _usrp_prims.FR_ADC_OFFSET_1
FR_ADC_OFFSET_2 = _usrp_prims.FR_ADC_OFFSET_2
FR_ADC_OFFSET_3 = _usrp_prims.FR_ADC_OFFSET_3
FR_ATR_MASK_0 = _usrp_prims.FR_ATR_MASK_0
FR_ATR_TXVAL_0 = _usrp_prims.FR_ATR_TXVAL_0
FR_ATR_RXVAL_0 = _usrp_prims.FR_ATR_RXVAL_0
FR_ATR_MASK_1 = _usrp_prims.FR_ATR_MASK_1
FR_ATR_TXVAL_1 = _usrp_prims.FR_ATR_TXVAL_1
FR_ATR_RXVAL_1 = _usrp_prims.FR_ATR_RXVAL_1
FR_ATR_MASK_2 = _usrp_prims.FR_ATR_MASK_2
FR_ATR_TXVAL_2 = _usrp_prims.FR_ATR_TXVAL_2
FR_ATR_RXVAL_2 = _usrp_prims.FR_ATR_RXVAL_2
FR_ATR_MASK_3 = _usrp_prims.FR_ATR_MASK_3
FR_ATR_TXVAL_3 = _usrp_prims.FR_ATR_TXVAL_3
FR_ATR_RXVAL_3 = _usrp_prims.FR_ATR_RXVAL_3
FR_ATR_CTL = _usrp_prims.FR_ATR_CTL
bmFR_ATR_CTL_EN = _usrp_prims.bmFR_ATR_CTL_EN
FR_INTERP_RATE = _usrp_prims.FR_INTERP_RATE
FR_DECIM_RATE = _usrp_prims.FR_DECIM_RATE
FR_RX_FREQ_0 = _usrp_prims.FR_RX_FREQ_0
FR_RX_FREQ_1 = _usrp_prims.FR_RX_FREQ_1
FR_RX_FREQ_2 = _usrp_prims.FR_RX_FREQ_2
FR_RX_FREQ_3 = _usrp_prims.FR_RX_FREQ_3
FR_RX_MUX = _usrp_prims.FR_RX_MUX
FR_TX_MUX = _usrp_prims.FR_TX_MUX
FR_TX_A_REFCLK = _usrp_prims.FR_TX_A_REFCLK
FR_RX_A_REFCLK = _usrp_prims.FR_RX_A_REFCLK
FR_TX_B_REFCLK = _usrp_prims.FR_TX_B_REFCLK
FR_RX_B_REFCLK = _usrp_prims.FR_RX_B_REFCLK
bmFR_REFCLK_EN = _usrp_prims.bmFR_REFCLK_EN
bmFR_REFCLK_DIVISOR_MASK = _usrp_prims.bmFR_REFCLK_DIVISOR_MASK
FR_RX_PHASE_0 = _usrp_prims.FR_RX_PHASE_0
FR_RX_PHASE_1 = _usrp_prims.FR_RX_PHASE_1
FR_RX_PHASE_2 = _usrp_prims.FR_RX_PHASE_2
FR_RX_PHASE_3 = _usrp_prims.FR_RX_PHASE_3
FR_TX_FORMAT = _usrp_prims.FR_TX_FORMAT
bmFR_TX_FORMAT_16_IQ = _usrp_prims.bmFR_TX_FORMAT_16_IQ
FR_RX_FORMAT = _usrp_prims.FR_RX_FORMAT
bmFR_RX_FORMAT_SHIFT_MASK = _usrp_prims.bmFR_RX_FORMAT_SHIFT_MASK
bmFR_RX_FORMAT_SHIFT_SHIFT = _usrp_prims.bmFR_RX_FORMAT_SHIFT_SHIFT
bmFR_RX_FORMAT_WIDTH_MASK = _usrp_prims.bmFR_RX_FORMAT_WIDTH_MASK
bmFR_RX_FORMAT_WIDTH_SHIFT = _usrp_prims.bmFR_RX_FORMAT_WIDTH_SHIFT
bmFR_RX_FORMAT_WANT_Q = _usrp_prims.bmFR_RX_FORMAT_WANT_Q
bmFR_RX_FORMAT_BYPASS_HB = _usrp_prims.bmFR_RX_FORMAT_BYPASS_HB
FR_USER_0 = _usrp_prims.FR_USER_0
FR_USER_1 = _usrp_prims.FR_USER_1
FR_USER_2 = _usrp_prims.FR_USER_2
FR_USER_3 = _usrp_prims.FR_USER_3
FR_USER_4 = _usrp_prims.FR_USER_4
FR_USER_5 = _usrp_prims.FR_USER_5
FR_USER_6 = _usrp_prims.FR_USER_6
FR_USER_7 = _usrp_prims.FR_USER_7
FR_USER_8 = _usrp_prims.FR_USER_8
FR_USER_9 = _usrp_prims.FR_USER_9
FR_USER_10 = _usrp_prims.FR_USER_10
FR_USER_11 = _usrp_prims.FR_USER_11
FR_USER_12 = _usrp_prims.FR_USER_12
FR_USER_13 = _usrp_prims.FR_USER_13
FR_USER_14 = _usrp_prims.FR_USER_14
FR_USER_15 = _usrp_prims.FR_USER_15

usrp_write_fpga_reg = _usrp_prims.usrp_write_fpga_reg

usrp_read_fpga_reg = _usrp_prims.usrp_read_fpga_reg

usrp_set_fpga_reset = _usrp_prims.usrp_set_fpga_reset

usrp_set_fpga_tx_enable = _usrp_prims.usrp_set_fpga_tx_enable

usrp_set_fpga_rx_enable = _usrp_prims.usrp_set_fpga_rx_enable

usrp_set_fpga_tx_reset = _usrp_prims.usrp_set_fpga_tx_reset

usrp_set_fpga_rx_reset = _usrp_prims.usrp_set_fpga_rx_reset

usrp_set_sleep_bits = _usrp_prims.usrp_set_sleep_bits

usrp_set_led = _usrp_prims.usrp_set_led

usrp_check_rx_overrun = _usrp_prims.usrp_check_rx_overrun

usrp_check_tx_underrun = _usrp_prims.usrp_check_tx_underrun

usrp_i2c_write = _usrp_prims.usrp_i2c_write

usrp_i2c_read = _usrp_prims.usrp_i2c_read

usrp_spi_write = _usrp_prims.usrp_spi_write

usrp_spi_read = _usrp_prims.usrp_spi_read

usrp_9862_write = _usrp_prims.usrp_9862_write

usrp_9862_read = _usrp_prims.usrp_9862_read

usrp_eeprom_write = _usrp_prims.usrp_eeprom_write

usrp_eeprom_read = _usrp_prims.usrp_eeprom_read

usrp_write_aux_dac = _usrp_prims.usrp_write_aux_dac

usrp_read_aux_adc = _usrp_prims.usrp_read_aux_adc

usrp_dbid_to_string = _usrp_prims.usrp_dbid_to_string


usrp_find_device = _usrp_prims.usrp_find_device

==> usrp-0.11.tar.gz: usrp-0.11/host/swig/usrp_prims.py <==
# This file was created automatically by SWIG 1.3.29.
# Don't modify this file, modify the SWIG interface instead.

import _usrp_prims
import new
new_instancemethod = new.instancemethod
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'PySwigObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if (name == "thisown"): return self.this.own(value)
        if hasattr(self,name) or (name == "this"):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


class PySwigIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    def __init__(self): raise AttributeError, "No constructor defined"
    __repr__ = _swig_repr
    __swig_destroy__ = _usrp_prims.delete_PySwigIterator
    __del__ = lambda self : None;
    def value(*args): return _usrp_prims.PySwigIterator_value(*args)
    def incr(*args): return _usrp_prims.PySwigIterator_incr(*args)
    def decr(*args): return _usrp_prims.PySwigIterator_decr(*args)
    def distance(*args): return _usrp_prims.PySwigIterator_distance(*args)
    def equal(*args): return _usrp_prims.PySwigIterator_equal(*args)
    def copy(*args): return _usrp_prims.PySwigIterator_copy(*args)
    def next(*args): return _usrp_prims.PySwigIterator_next(*args)
    def previous(*args): return _usrp_prims.PySwigIterator_previous(*args)
    def advance(*args): return _usrp_prims.PySwigIterator_advance(*args)
    def __eq__(*args): return _usrp_prims.PySwigIterator___eq__(*args)
    def __ne__(*args): return _usrp_prims.PySwigIterator___ne__(*args)
    def __iadd__(*args): return _usrp_prims.PySwigIterator___iadd__(*args)
    def __isub__(*args): return _usrp_prims.PySwigIterator___isub__(*args)
    def __add__(*args): return _usrp_prims.PySwigIterator___add__(*args)
    def __sub__(*args): return _usrp_prims.PySwigIterator___sub__(*args)
    def __iter__(self): return self
PySwigIterator_swigregister = _usrp_prims.PySwigIterator_swigregister
PySwigIterator_swigregister(PySwigIterator)

ULS_ERROR = _usrp_prims.ULS_ERROR
ULS_OK = _usrp_prims.ULS_OK
ULS_ALREADY_LOADED = _usrp_prims.ULS_ALREADY_LOADED
usrp_one_time_init = _usrp_prims.usrp_one_time_init
usrp_rescan = _usrp_prims.usrp_rescan
usrp_usrp_p = _usrp_prims.usrp_usrp_p
usrp_usrp0_p = _usrp_prims.usrp_usrp0_p
usrp_usrp1_p = _usrp_prims.usrp_usrp1_p
usrp_usrp2_p = _usrp_prims.usrp_usrp2_p
usrp_hw_rev = _usrp_prims.usrp_hw_rev
usrp_fx2_p = _usrp_prims.usrp_fx2_p
usrp_unconfigured_usrp_p = _usrp_prims.usrp_unconfigured_usrp_p
usrp_configured_usrp_p = _usrp_prims.usrp_configured_usrp_p
usrp_open_cmd_interface = _usrp_prims.usrp_open_cmd_interface
usrp_open_rx_interface = _usrp_prims.usrp_open_rx_interface
usrp_open_tx_interface = _usrp_prims.usrp_open_tx_interface
usrp_close_interface = _usrp_prims.usrp_close_interface
usrp_load_firmware = _usrp_prims.usrp_load_firmware
usrp_load_firmware_nth = _usrp_prims.usrp_load_firmware_nth
usrp_load_fpga = _usrp_prims.usrp_load_fpga
usrp_load_standard_bits = _usrp_prims.usrp_load_standard_bits
FR_TX_SAMPLE_RATE_DIV = _usrp_prims.FR_TX_SAMPLE_RATE_DIV
FR_RX_SAMPLE_RATE_DIV = _usrp_prims.FR_RX_SAMPLE_RATE_DIV
FR_MASTER_CTRL = _usrp_prims.FR_MASTER_CTRL
bmFR_MC_ENABLE_TX = _usrp_prims.bmFR_MC_ENABLE_TX
bmFR_MC_ENABLE_RX = _usrp_prims.bmFR_MC_ENABLE_RX
bmFR_MC_RESET_TX = _usrp_prims.bmFR_MC_RESET_TX
bmFR_MC_RESET_RX = _usrp_prims.bmFR_MC_RESET_RX
FR_OE_0 = _usrp_prims.FR_OE_0
FR_OE_1 = _usrp_prims.FR_OE_1
FR_OE_2 = _usrp_prims.FR_OE_2
FR_OE_3 = _usrp_prims.FR_OE_3
FR_IO_0 = _usrp_prims.FR_IO_0
FR_IO_1 = _usrp_prims.FR_IO_1
FR_IO_2 = _usrp_prims.FR_IO_2
FR_IO_3 = _usrp_prims.FR_IO_3
FR_MODE = _usrp_prims.FR_MODE
bmFR_MODE_NORMAL = _usrp_prims.bmFR_MODE_NORMAL
bmFR_MODE_LOOPBACK = _usrp_prims.bmFR_MODE_LOOPBACK
bmFR_MODE_RX_COUNTING = _usrp_prims.bmFR_MODE_RX_COUNTING
FR_DEBUG_EN = _usrp_prims.FR_DEBUG_EN
bmFR_DEBUG_EN_TX_A = _usrp_prims.bmFR_DEBUG_EN_TX_A
bmFR_DEBUG_EN_RX_A = _usrp_prims.bmFR_DEBUG_EN_RX_A
bmFR_DEBUG_EN_TX_B = _usrp_prims.bmFR_DEBUG_EN_TX_B
bmFR_DEBUG_EN_RX_B = _usrp_prims.bmFR_DEBUG_EN_RX_B
FR_DC_OFFSET_CL_EN = _usrp_prims.FR_DC_OFFSET_CL_EN
FR_ADC_OFFSET_0 = _usrp_prims.FR_ADC_OFFSET_0
FR_ADC_OFFSET_1 = _usrp_prims.FR_ADC_OFFSET_1
FR_ADC_OFFSET_2 = _usrp_prims.FR_ADC_OFFSET_2
FR_ADC_OFFSET_3 = _usrp_prims.FR_ADC_OFFSET_3
FR_ATR_MASK_0 = _usrp_prims.FR_ATR_MASK_0
FR_ATR_TXVAL_0 = _usrp_prims.FR_ATR_TXVAL_0
FR_ATR_RXVAL_0 = _usrp_prims.FR_ATR_RXVAL_0
FR_ATR_MASK_1 = _usrp_prims.FR_ATR_MASK_1
FR_ATR_TXVAL_1 = _usrp_prims.FR_ATR_TXVAL_1
FR_ATR_RXVAL_1 = _usrp_prims.FR_ATR_RXVAL_1
FR_ATR_MASK_2 = _usrp_prims.FR_ATR_MASK_2
FR_ATR_TXVAL_2 = _usrp_prims.FR_ATR_TXVAL_2
FR_ATR_RXVAL_2 = _usrp_prims.FR_ATR_RXVAL_2
FR_ATR_MASK_3 = _usrp_prims.FR_ATR_MASK_3
FR_ATR_TXVAL_3 = _usrp_prims.FR_ATR_TXVAL_3
FR_ATR_RXVAL_3 = _usrp_prims.FR_ATR_RXVAL_3
FR_INTERP_RATE = _usrp_prims.FR_INTERP_RATE
FR_DECIM_RATE = _usrp_prims.FR_DECIM_RATE
FR_RX_FREQ_0 = _usrp_prims.FR_RX_FREQ_0
FR_RX_FREQ_1 = _usrp_prims.FR_RX_FREQ_1
FR_RX_FREQ_2 = _usrp_prims.FR_RX_FREQ_2
FR_RX_FREQ_3 = _usrp_prims.FR_RX_FREQ_3
FR_RX_MUX = _usrp_prims.FR_RX_MUX
FR_TX_MUX = _usrp_prims.FR_TX_MUX
FR_TX_A_REFCLK = _usrp_prims.FR_TX_A_REFCLK
FR_RX_A_REFCLK = _usrp_prims.FR_RX_A_REFCLK
FR_TX_B_REFCLK = _usrp_prims.FR_TX_B_REFCLK
FR_RX_B_REFCLK = _usrp_prims.FR_RX_B_REFCLK
bmFR_REFCLK_EN = _usrp_prims.bmFR_REFCLK_EN
bmFR_REFCLK_DIVISOR_MASK = _usrp_prims.bmFR_REFCLK_DIVISOR_MASK
FR_RX_PHASE_0 = _usrp_prims.FR_RX_PHASE_0
FR_RX_PHASE_1 = _usrp_prims.FR_RX_PHASE_1
FR_RX_PHASE_2 = _usrp_prims.FR_RX_PHASE_2
FR_RX_PHASE_3 = _usrp_prims.FR_RX_PHASE_3
FR_TX_FORMAT = _usrp_prims.FR_TX_FORMAT
bmFR_TX_FORMAT_16_IQ = _usrp_prims.bmFR_TX_FORMAT_16_IQ
FR_RX_FORMAT = _usrp_prims.FR_RX_FORMAT
bmFR_RX_FORMAT_SHIFT_MASK = _usrp_prims.bmFR_RX_FORMAT_SHIFT_MASK
bmFR_RX_FORMAT_SHIFT_SHIFT = _usrp_prims.bmFR_RX_FORMAT_SHIFT_SHIFT
bmFR_RX_FORMAT_WIDTH_MASK = _usrp_prims.bmFR_RX_FORMAT_WIDTH_MASK
bmFR_RX_FORMAT_WIDTH_SHIFT = _usrp_prims.bmFR_RX_FORMAT_WIDTH_SHIFT
bmFR_RX_FORMAT_WANT_Q = _usrp_prims.bmFR_RX_FORMAT_WANT_Q
bmFR_RX_FORMAT_BYPASS_HB = _usrp_prims.bmFR_RX_FORMAT_BYPASS_HB
FR_USER_0 = _usrp_prims.FR_USER_0
FR_USER_1 = _usrp_prims.FR_USER_1
FR_USER_2 = _usrp_prims.FR_USER_2
FR_USER_3 = _usrp_prims.FR_USER_3
FR_USER_4 = _usrp_prims.FR_USER_4
FR_USER_5 = _usrp_prims.FR_USER_5
FR_USER_6 = _usrp_prims.FR_USER_6
FR_USER_7 = _usrp_prims.FR_USER_7
FR_USER_8 = _usrp_prims.FR_USER_8
FR_USER_9 = _usrp_prims.FR_USER_9
FR_USER_10 = _usrp_prims.FR_USER_10
FR_USER_11 = _usrp_prims.FR_USER_11
FR_USER_12 = _usrp_prims.FR_USER_12
FR_USER_13 = _usrp_prims.FR_USER_13
FR_USER_14 = _usrp_prims.FR_USER_14
FR_USER_15 = _usrp_prims.FR_USER_15
FR_RB_IO_RX_A_IO_TX_A = _usrp_prims.FR_RB_IO_RX_A_IO_TX_A
FR_RB_IO_RX_B_IO_TX_B = _usrp_prims.FR_RB_IO_RX_B_IO_TX_B
FR_RB_CAPS = _usrp_prims.FR_RB_CAPS
bmFR_RB_CAPS_NDDC_MASK = _usrp_prims.bmFR_RB_CAPS_NDDC_MASK
bmFR_RB_CAPS_NDDC_SHIFT = _usrp_prims.bmFR_RB_CAPS_NDDC_SHIFT
bmFR_RB_CAPS_RX_HAS_HALFBAND = _usrp_prims.bmFR_RB_CAPS_RX_HAS_HALFBAND
bmFR_RB_CAPS_NDUC_MASK = _usrp_prims.bmFR_RB_CAPS_NDUC_MASK
bmFR_RB_CAPS_NDUC_SHIFT = _usrp_prims.bmFR_RB_CAPS_NDUC_SHIFT
bmFR_RB_CAPS_TX_HAS_HALFBAND = _usrp_prims.bmFR_RB_CAPS_TX_HAS_HALFBAND
usrp_write_fpga_reg = _usrp_prims.usrp_write_fpga_reg
usrp_read_fpga_reg = _usrp_prims.usrp_read_fpga_reg
usrp_set_fpga_reset = _usrp_prims.usrp_set_fpga_reset
usrp_set_fpga_tx_enable = _usrp_prims.usrp_set_fpga_tx_enable
usrp_set_fpga_rx_enable = _usrp_prims.usrp_set_fpga_rx_enable
usrp_set_fpga_tx_reset = _usrp_prims.usrp_set_fpga_tx_reset
usrp_set_fpga_rx_reset = _usrp_prims.usrp_set_fpga_rx_reset
usrp_set_led = _usrp_prims.usrp_set_led
usrp_check_rx_overrun = _usrp_prims.usrp_check_rx_overrun
usrp_check_tx_underrun = _usrp_prims.usrp_check_tx_underrun
usrp_i2c_write = _usrp_prims.usrp_i2c_write
usrp_i2c_read = _usrp_prims.usrp_i2c_read
usrp_spi_write = _usrp_prims.usrp_spi_write
usrp_spi_read = _usrp_prims.usrp_spi_read
usrp_9862_write = _usrp_prims.usrp_9862_write
usrp_9862_read = _usrp_prims.usrp_9862_read
usrp_eeprom_write = _usrp_prims.usrp_eeprom_write
usrp_eeprom_read = _usrp_prims.usrp_eeprom_read
usrp_write_aux_dac = _usrp_prims.usrp_write_aux_dac
usrp_read_aux_adc = _usrp_prims.usrp_read_aux_adc
usrp_serial_number = _usrp_prims.usrp_serial_number
usrp_dbid_to_string = _usrp_prims.usrp_dbid_to_string

usrp_find_device = _usrp_prims.usrp_find_device
